@@ -5,7 +5,8 @@ use warnings;
 package Dist::Iller::DocType::Gitignore;
 
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.1408';
+# ABSTRACT: Turn the Dist::Iller config into a .gitignore file
+our $VERSION = '0.1409';
 
 use Dist::Iller::Elk;
 use Path::Tiny;
@@ -14,26 +15,20 @@ with qw/
     Dist::Iller::DocType
 /;
 
-has always => (
-    is => 'ro',
-    isa => ArrayRef[Str],
-    traits => ['Array'],
-    default => sub { [ ] },
-    handles => {
-        add_always => 'push',
-        all_always => 'elements',
-    },
-);
-has onexist => (
-    is => 'ro',
-    isa => ArrayRef[Str],
-    traits => ['Array'],
-    default => sub { [ ] },
-    handles => {
-        add_onexists => 'push',
-        all_onexists => 'elements',
-    },
-);
+for my $setting (qw/always onexist/) {
+    has $setting => (
+        is => 'ro',
+        isa => ArrayRef[Str],
+        traits => ['Array'],
+        default => sub { [ ] },
+        handles => {
+            "add_$setting" => 'push',
+            "all_$setting" => 'elements',
+            "get_$setting" => 'get',
+            "set_$setting" => 'set',
+        },
+    );
+}
 
 sub comment_start { '#' }
 
@@ -58,14 +53,26 @@ sub parse {
         $self->add_always($_) for @{ $yaml->{'always'} };
     }
     if(exists $yaml->{'onexist'}) {
-        $self->add_onexists($_) for grep { path($_)->exists } @{ $yaml->{'onexist'} };
+        $self->add_onexist($_) for grep { path($_)->exists } @{ $yaml->{'onexist'} };
+    }
+
+    if ($self->global && $self->global->has_distribution_name) {
+        for my $type (qw/always onexist/) {
+            my $all = "all_$type";
+            my $get = "get_$type";
+            my $set = "set_$type";
+            for my $index (0.. scalar $self->$all - 1) {
+                my $item = $self->$get($index);
+                $self->$set($index, '/'.$self->global->distribution_name.'-*') if $item eq '$self.distribution_name';
+            }
+        }
     }
 }
 
 sub to_string {
     my $self = shift;
 
-    return join "\n", ($self->all_always, $self->all_onexists, '');
+    return join "\n", ($self->all_always, $self->all_onexist, '');
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -80,11 +87,11 @@ __END__
 
 =head1 NAME
 
-Dist::Iller::DocType::Gitignore
+Dist::Iller::DocType::Gitignore - Turn the Dist::Iller config into a .gitignore file
 
 =head1 VERSION
 
-Version 0.1408, released 2016-03-12.
+Version 0.1409, released 2020-12-27.
 
 =head1 SOURCE
 
