@@ -5,7 +5,8 @@ use warnings;
 package Dist::Iller::Elk;
 
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.1408';
+# ABSTRACT: A slightly extended Moose
+our $VERSION = '0.1409';
 
 use Moose();
 use MooseX::AttributeShortcuts();
@@ -36,11 +37,11 @@ __END__
 
 =head1 NAME
 
-Dist::Iller::Elk
+Dist::Iller::Elk - A slightly extended Moose
 
 =head1 VERSION
 
-Version 0.1408, released 2016-03-12.
+Version 0.1409, released 2020-12-27.
 
 =head1 SOURCE
 
